==========================
 Invenio-Logging v1.0.0b3
==========================

Invenio-Logging v1.0.0b3 was released on August 18, 2017.

About
-----

Module providing logging capabilities

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-logging==1.0.0b3

Documentation
-------------

   https://invenio-logging.readthedocs.io/

Happy hacking and thanks for flying Invenio-Logging.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-logging
|   URL: http://inveniosoftware.org
